<?php
namespace Teknisa\MAN\Controllers;


use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Utilities;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\MAN\Services\CustomizacaoTAAservice;
use Teknisa\MAN\Services\FileUploaderService;
use Zeedhi\Framework\Util\Functions;

class CustomizacaoTAA extends  \Teknisa\MAN\Controllers\TeknisaCrud {
    
    const dataSourceCores = 'customizacaoTAAcores';
    const dataSourceImagens = 'customizacaoTAAimagens';

	protected $dataSourceManager;
	protected $parameterBagColumns = ['NRORG'];
    protected $customizacaoTAAservice;
    protected $fileUploaderService;
    protected $environment;
    protected $utilService;
    
    public function __construct ($crudService, $parameterBag, $entityManager, Utilities\Util $utilService, $dataSourceManager, $customizacaoTAAservice, $fileUploaderService, $environment) {
        
        $this->crudService                  = $crudService;
        $this->parameterBag                 = $parameterBag;
        $this->entityManager                = $entityManager;
        $this->utilService                  = $utilService;
        $this->dataSourceManager            = $dataSourceManager;
        $this->fileUploaderService          = $fileUploaderService;
        $this->CustomizacaoTAAservice       = $customizacaoTAAservice;
        $this->environment                  = $environment;
    }

    public function findCores(DTO\Request\Filter $request, DTO\Response $response) {
        $sql = "SELECT CORESJSON, NRORG, '' AS blabla FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG";
        $coresPadrao = '{"DSCORPRIMARIA":2189567, "DSCORPRIMARIASUAVE":5348095,"DSCORPRIMARIAESCURA":14020,"DSCORCABECALHO":1728760,"DSCORCATEGORIAS":16777215,"DSCORFONTECATEGORIAS":2039582,"DSCORFUNDOCARRINHO":14803426, "DSCORFONTEPRECO":255}';
        
        $conn = $this->entityManager->getConnection();
        $statement = $conn->prepare($sql);
        $NRORG = $this->environment->getNrOrgTrab();
        $params = ["NRORG" => $NRORG];
        $statement->execute($params);
        $result = $statement->fetchAll();
        if(isset($result[0]['CORESJSON'])){
           $CORESJSON = [json_decode($result[0]['CORESJSON'])];
           $response->addDataSet(new DataSet(self::dataSourceImagens, $CORESJSON));
        } else {
          $CORESJSON = [json_decode($coresPadrao)];
          $response->addDataSet(new DataSet(self::dataSourceImagens, $CORESJSON));
        }
    }
    
    public function findImagens(DTO\Request\Filter $request, DTO\Response $response) {
        $sql = "SELECT JSONB64CUSTOMMEDIA, NRORG, '' AS blabla FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG";
        $conn = $this->entityManager->getConnection();
        $statement = $conn->prepare($sql);    
        $NRORG = $this->environment->getNrOrgTrab();
        $params = ["NRORG" => $NRORG];
        $statement->execute($params);
        $result = $statement->fetchAll();
        if(isset($result[0]['JSONB64CUSTOMMEDIA'])){
            $JSONB64CUSTOMMEDIA = [json_decode($result[0]['JSONB64CUSTOMMEDIA'])];
            $response->addDataSet(new DataSet(self::dataSourceImagens, $JSONB64CUSTOMMEDIA, $params));
        } else {
            // $JSONB64CUSTOMMEDIA = [json_decode($statement->fetchAll()[0]['JSONB64CUSTOMMEDIA'])];
            // $response->addDataSet(new DataSet(self::dataSourceImagens, $JSONB64CUSTOMMEDIA, $params));
        return false;
        }
    }
    
    public function saveCores(DTO\Request\DataSet $request,DTO\Response $response){
    	try {
    	    $this->dataSourceName = self::dataSourceCores;
    	    $rows = $request->getDataSet()->getRows();
    	    $NRORG = $rows[0]['NRORG'];
    	    unset($rows[0]['NRORG']);
            unset($rows[0]['__createdLocal']);
            unset($rows[0]['__is_new']);
            unset($rows[0]['changed']);
    	    $rows[0] = json_encode($rows[0]);
    	    $paramsCores = array( 
    	                    'CORESJSON'     =>    $rows[0],
                            'NRORG'                  =>    $NRORG
                        );
            $this->CustomizacaoTAAservice->saveColors($paramsCores);
            $response->addDataSet(new DataSet($this->dataSourceName,array('CORESJSON'=>$paramsCores['CORESJSON'],'NRORG'=>$paramsCores['NRORG'])));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function saveImagens(DTO\Request\DataSet $request,DTO\Response $response){
    
    	try {
    	    
    	    $this->dataSourceName = self::dataSourceImagens;
    	    $rows = $request->getDataSet()->getRows();
    	    
    	    $NRORG = $rows[0]['NRORG'];
    	    unset($rows[0]['NRORG']);
    	    unset($rows[0]['NRORGULTATU']);
            unset($rows[0]['CDOPERULTATU']);
            unset($rows[0]['DTULTATU']);
            unset($rows[0]['__is_new']);
            unset($rows[0]['changed']);
    	    $rows[0] = json_encode($rows[0]);
    	    $paramsImagens = array( 
    	                    'JSONB64CUSTOMMEDIA'     =>    $rows[0],
                            'NRORG'                  =>    $NRORG
                        );
            
            $this->CustomizacaoTAAservice->saveImages($paramsImagens);
            $response->addDataSet(new DataSet($this->dataSourceName,array('JSONB64CUSTOMMEDIA'=>$paramsImagens['JSONB64CUSTOMMEDIA'],'NRORG'=>$paramsImagens['NRORG'])));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
}
