<?php
namespace Teknisa\MAN\Controllers;


use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Utilities;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\MAN\Services\ProdGrupoPromocionalService;
use Teknisa\MAN\Services\FileUploaderService;
use Zeedhi\Framework\Util\Functions;

class ProdGrupoPromocional extends  \Teknisa\MAN\Controllers\TeknisaCrud {

	protected $dataSourceName = 'vnd41000_grupoPromo_prod';
	protected $parameterBagColumns = array('NRORG', 'CDGRUPROMOC');
    protected $prodGrupoPromocionalService;
    protected $fileUploaderService;
    
    public function __construct ($crudService, $parameterBag, $entityManager, Utilities\Util $utilService, Manager $dataSourceManager, ProdGrupoPromocionalService $prodGrupoPromocionalService, FileUploaderService $fileUploaderService) {
        $this->crudService                  = $crudService;
        $this->parameterBag                 = $parameterBag;
        $this->entityManager                = $entityManager;
        $this->utilService                  = $utilService;
        $this->dataSourceManager            = $dataSourceManager;
        $this->ProdGrupoPromocionalService  = $prodGrupoPromocionalService;
        $this->fileUploaderService          = $fileUploaderService;
    }

    public function findGruPromProd(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = 'vnd41000_grupoPromo_prod';
        parent::find($request, $response);
    }
    
    private function saveUnitarioPromoProd(&$row, &$request, &$response) {
        try {
            if(Functions::arrayKeyExists('DSENDEIMGPROMO', $row)) {
                $this->fileUploaderService->setImageForSave($row, 'DSENDEIMGPROMO', 'DSENDEIMGPROMO');
            }
        	self::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
	public function deleteProd(DTO\Request\DataSet $request, DTO\Response $response) {
		try {
            $rows = $request->getDataSet()->getRows();
		    foreach ($rows as $product) {
                $this->ProdGrupoPromocionalService->deleteDescProd($product['CDPRODUTO'], $product['CDGRUPROMOC'], $product['NRORG']);
		    }
        	self::delete($request, $response);
		} catch (\Exception $e) {
		    $response->addNotification(new Notification($e->getMessage(), Notification::TYPE_ERROR));
		}
	}
    
	public function save(DTO\Request $request, DTO\Response $response) {
		try {
			$dataSourceName = $this->dataSourceNameToSave ? $this->dataSourceNameToSave : $this->dataSourceName;
			$rows = $this->crudService->getRowsToSave($request, $dataSourceName);
			$this->crudService->save($dataSourceName, $rows);
		} catch (\Exception $e) {
		    $response->addNotification(new Notification($e->getMessage(), Notification::TYPE_ERROR));
		}
	}
    
    private function saveAutoCadGruPromoProd($row, &$response) {
        $parameters = array(
            'NRORG'         => $row['NRORG'],
            'CDGRUPROMOC'   => $row['CDGRUPROMOC'],
            'CDARVPRODF'    => $row['CDARVPRODF'],
            'CDARVPRODI'    => $row['CDARVPRODI'],
            'CDNVPRODUTO'   => $row['CDNVPRODUTO']
        );
        
        try {
            $products = $this->entityManager->getConnection()->executeQuery(self::GET_PROD_AUTO, $parameters)->fetchAll();  
            
            foreach ($products as $product) {
                $product['CDOPERADOR']  = $row['CDOPERINCLUSAO'];
                $product['DTULTATU']    = $row['DTINCLUSAO'];
                $product['CDGRUPROMOC'] = $row['CDGRUPROMOC'];
                
                $this->ProdGrupoPromocionalService->saveProductsArray( $product['CDGRUPROMOC'],
                                                $product['CDPRODUTO'], $product['CDARVPROD'],  
                                                $product['NMPRODUTO'], $product['NRORG'], 
                                                $product['CDOPERADOR'], $product['DTULTATU'] );
            }
            
            $response->addDataSet(new DataSet ('vnd41000_grupoPromo_prod', $products));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function saveGruPromoProd(DTO\Request\DataSet $request, DTO\Response $response){
        $rows = $request->getDataSet()->getRows();
        
        try {
            if(count($rows) === 1) {
                $row = $rows[0];
                if(Functions::arrayKeyExists('CDPRODUTOI', $row) && !!$row['CDPRODUTOI'] && 
                   Functions::arrayKeyExists('CDPRODUTOF', $row) && !!$row['CDPRODUTOF']) {
                    self::saveAutoCadGruPromoProd($row, $response);
                } else {
                    self::saveUnitarioPromoProd($row, $request, $response);
                }
            }
        } catch(\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    const GET_PROD_AUTO = "
        SELECT DISTINCT CDPRODUTO, CDARVPROD, NMPRODUTO, NRORG 
            FROM PRODUTO          
            WHERE NRORG = :NRORG 
                AND CDARVPROD BETWEEN :CDARVPRODI AND :CDARVPRODF 
                AND CDNVPRODUTO = :CDNVPRODUTO
                AND CDPRODUTO NOT IN (SELECT CDPRODUTO FROM PRODGRUPROMOC WHERE CDGRUPROMOC = :CDGRUPROMOC AND NRORG = :NRORG ) 
        ORDER BY CDARVPROD";
}